@@ -71,7 +71,7 @@ class ExpressionDescriptor:
                 raise WrongArgumentException("Unknown {} configuration argument".format(kwarg))
 
         # Initializes localization
-        self.get_text = GetText(options.locale_code)
+        self.get_text = GetText(options.locale_code, options.locale_location)
 
     def _(self, message):
         return self.get_text.trans.gettext(message)
@@ -120,7 +120,7 @@ class ExpressionDescriptor:
         Returns:
             The FULL description
         Raises:
-            FormatException: if formating fails and throw_exception_on_parse_error is True
+            FormatException: if formatting fails and throw_exception_on_parse_error is True
 
         """
 
@@ -142,7 +142,8 @@ class ExpressionDescriptor:
             description = ExpressionDescriptor.transform_case(description, self._options.casing_type)
         except Exception:
             description = self._(
-                "An error occurred when generating the expression description.  Check the cron expression syntax.")
+                "An error occurred when generating the expression description.  Check the cron expression syntax."
+            )
             if self._options.throw_exception_on_parse_error:
                 raise FormatException(description)
 
@@ -553,7 +554,7 @@ class ExpressionDescriptor:
         minute_expression,
         second_expression=''
     ):
-        """Given time parts, will contruct a formatted time description
+        """Given time parts, will construct a formatted time description
         Args:
             hour_expression: Hours part
             minute_expression: Minutes part
